/**
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 *
 * You should have find a copy of NFSChina License. If not, please contact us
 * by email <os_support@nfschina.com>
 *
**/

import QtQuick 2.7
import QtQuick.Layouts 1.3
import QtQuick.Controls 2.0

import org.kde.kcoreaddons 1.0 as KCoreAddons
import org.kde.kcm 1.3
import org.kde.kirigami 2.13 as Kirigami
import org.kde.plasma.core 2.1 as PlasmaCore
import org.kde.plasma.private.volume 0.1
import QtGraphicalEffects 1.15


Kirigami.Page {
    id: systemSoundsConfigPage
    title: i18n("Apps Sound")

    property var config
    property var paSinkModel
    property bool lighttheme:PlasmaCore.Theme.viewBackgroundColor=="#ffffff"
    property var backgroundcolor: PlasmaCore.Theme.viewBackgroundColor
    property var textcolor:PlasmaCore.Theme.textColor
    property var bordercolor:lighttheme?"#CCCCCC":"#2D2D2D"
    property var spaceline:lighttheme?"#F0F0F0":"#2D2D2D"
    property int leftAndRightMargin: 24

    ColumnLayout {
        id: customizeRect
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        width:558
        spacing: 6

//        // playback Streams
//        Text {
//            id: playbackStreamsLabel
//            visible: false
//            height: eventStreamView.visible ? 20 : 0
//            anchors {
//                top: parent.top
//                left: parent.left
//            }
//            text: i18nd("kcm_pulseaudio", "Playback Streams")
//            font.pixelSize: 14
//            color: textcolor
//            font.family: "SourceHanSansSC-Regular"
//        }

        Rectangle {
            id: playbackStreamsLabelRect
            //anchors.top: playbackStreamsLabel.bottom
            color: backgroundcolor
            height: eventStreamView.height
            width:558
            border.color: bordercolor
            border.width: 1
            radius: 10

            ListView {
                id: eventStreamView
                visible: count > 0
                anchors {
                    verticalCenter: parent.verticalCenter
                    top: parent.top
                    bottom: parent.bottom
                    left: parent.left
                    right: parent.right
                    leftMargin: leftAndRightMargin
                    rightMargin: leftAndRightMargin
                    topMargin: 16
                    bottomMargin: 16
                }
                interactive: false
                spacing: Kirigami.Units.largeSpacing
                model: PulseObjectFilterModel {
                    filters: [ { role: "Name", value: "sink-input-by-media-role:event" } ]
                    sourceModel: StreamRestoreModel {}
                }
                delegate: StreamListItem {
                    deviceModel: paSinkModel
                    isPlayback: true
                }
                onCountChanged: {
                    eventStreamView.height = count > 0 ? count * currentItem.height : 0
                    playbackStreamsLabelRect.height = count > 0 ? count * currentItem.height + 2 * 16 : 0
                }
            }
        }

        // apps
        Rectangle {
            id: sinkInputViewRect
            color: backgroundcolor
            height: sinkInputView.height
            width:558
            border.color: bordercolor
            border.width: 1
            radius: 10
            ListView {
                id: sinkInputView
                visible: count > 0
                anchors {
                    verticalCenter: parent.verticalCenter
                    top: parent.top
                    bottom: parent.bottom
                    left: parent.left
                    right: parent.right
                    leftMargin: leftAndRightMargin
                    rightMargin: leftAndRightMargin
                    topMargin: 16
                    bottomMargin: 16
                }
                interactive: false
                spacing: Kirigami.Units.largeSpacing
                model: PulseObjectFilterModel {
                    filters: [ { role: "VirtualStream", value: false } ]
                    sourceModel: SinkInputModel {}
                }
                delegate: StreamListItem {
                    deviceModel: paSinkModel
                    isPlayback: true
                }
                onCountChanged: {
                    sinkInputView.height = count > 0 ? count * currentItem.height : 0
                    sinkInputViewRect.height = count > 0 ? count * currentItem.height + 2 * 16 : 0
                }
            }
        }
    }
}
