/**
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 *
 * You should have find a copy of NFSChina License. If not, please contact us
 * by email <os_support@nfschina.com>
 *
**/

import QtQuick 2.7
import QtQuick.Layouts 1.1
import QtQuick.Controls 2.15 as QQC2
import org.kde.kirigami 2.15 as Kirigami
import org.kde.plasma.private.volume 0.1
import QtQuick.Controls 2.3 as QtControls
import org.kde.plasma.core 2.1 as PlasmaCore

Item {

    property bool lighttheme:PlasmaCore.Theme.viewBackgroundColor=="#ffffff"
    property var backgroundcolor: PlasmaCore.Theme.viewBackgroundColor
    property var textcolor:PlasmaCore.Theme.textColor
    property var bordercolor:lighttheme?"#CCCCCC":"#2D2D2D"
    property var spaceline:lighttheme?"#F0F0F0":"#2D2D2D"
    property int leftAndRightMargin: 24
    property string name

    height: 47
    Layout.fillWidth: true

    Rectangle {
        id: item

        anchors.fill: parent
        color: "transparent"

        Text {
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: leftAndRightMargin
            text: i18nd("kcm_pulseaudio", name)
            font.pixelSize: 14
            color: textcolor
            font.family: "SourceHanSansSC-Regular"
        }

        QtControls.Switch {
            id: control
            anchors.verticalCenter:parent.verticalCenter
            anchors.right: parent.right
            anchors.rightMargin: leftAndRightMargin
            checked: name !== "Volume Adjust" ? sounds.getSoundState(name) : config.audioFeedback
            onClicked: {
                console.log(" op checked:", checked)
                if (name !== "Volume Adjust") {
                    sounds.setSound(name, checked)
                } else {
                    config.audioFeedback = checked
                    config.save()
                }
            }
            indicator: Rectangle {
                implicitWidth: 36
                implicitHeight: 20
                radius: 10
                color: control.checked ? "#007AFF" : "#808080"
                Rectangle {
                    id : smallRect
                    anchors.verticalCenter:parent.verticalCenter
                    width: 16
                    height: 16
                    radius: 8
                    color: control.down ? "#cccccc" : "#ffffff"
                    border.color: control.checked ? (control.down ? "#17a81a" : "#007AFF") : "#999999"
                    NumberAnimation on x{
                        to: control.width - smallRect.width-7
                        running: control.checked ? true : false
                        duration: 200
                    }
                    NumberAnimation on x{
                        to: 0
                        running: control.checked ? false : true
                        duration: 200
                    }
                }
            }
        }

        Rectangle{
            id: customizeSeparator
            anchors.top: parent.top
            anchors.topMargin: 47
            width:parent.width
            color:spaceline
            height:1
        }
    }
}
